*************
API Reference
*************


.. module:: flask_googlestorage


GoogleStorage
=============

.. autoclass:: flask_googlestorage.GoogleStorage
    :members:
    
Buckets
=======

.. autoclass:: flask_googlestorage.Bucket
    :members:

.. autoclass:: flask_googlestorage.LocalBucket
    :members:
  
.. autoclass:: flask_googlestorage.CloudBucket
    :members:

Utils
=====

.. autofunction:: flask_googlestorage.utils.get_state
.. autofunction:: flask_googlestorage.utils.secure_path

Exceptions
==========

.. automodule:: flask_googlestorage.exceptions
    :members: